# Changelog

## 1.1.0
* Add `@truthy_cached_property`

## 1.0.3
* Converted README from markdown to reStructuredText so it works on PyPi.

## 1.0.2
* Adds Python 3 support

## 1.0.1
* Fixes issue with caching only the last result in case of calling the chain of cached
properties

## 1.0.0
* Moves everything to `__init__.py`

## 0.1.0
* Adds `is_property_cached` function
